@@ -1,5 +1,8 @@
 import asyncio
 import typing
+from enum import Enum
+
+from pydantic import BaseModel
 
 from nexios.dependencies import Context, current_context
 from nexios.http import Request, Response
@@ -7,8 +10,24 @@ from nexios.http.response import BaseResponse
 from nexios.types import ASGIApp, Receive, Scope, Send
 from nexios.utils.async_helpers import is_async_callable
 from nexios.utils.concurrency import run_in_threadpool
-from pydantic import BaseModel
-from enum import Enum
+
+
+def _process_response(
+    response_manager: Response, func_result: typing.Any
+) -> Response:
+    """
+    Process the response from the function
+    """
+    if isinstance(func_result, (dict, list, str, int, float)):
+        response_manager.json(func_result)
+
+    elif isinstance(func_result, BaseResponse):
+        response_manager.make_response(func_result)
+    elif isinstance(func_result, BaseModel):
+        response_manager.json(func_result.model_dump())
+    elif isinstance(func_result, Enum):
+        response_manager.json(func_result.value)
+    return response_manager.get_response()
 
 
 async def request_response(
@@ -47,16 +66,7 @@ async def request_response(
                 )
         finally:
             current_context.reset(token)
-        if isinstance(func_result, (dict, list, str, int, float)):
-            response_manager.json(func_result)
-
-        elif isinstance(func_result, BaseResponse):
-            response_manager.make_response(func_result)
-        elif isinstance(func_result, BaseModel):
-            response_manager.json(func_result.model_dump())
-        elif isinstance(func_result, Enum):
-            response_manager.json(func_result.value)
-        response = response_manager.get_response()
+        response =  _process_response(response_manager, func_result)
         return await response(scope, receive, send)
 
     return app
