@@ -10,6 +10,7 @@ from typing import (
     Type,
     Union,
 )
+from typing import Literal
 
 from pydantic import BaseModel
 from typing_extensions import Annotated, Doc
@@ -119,7 +120,6 @@ class NexiosApp(object):
         self.config.update(
             get_nexios_config(),
         )
-        self.server_error_handler = None
         self.ws_router = WSRouter()
         self.ws_routes: List[WebsocketRoutes] = []
         self.http_middleware: List[Middleware] = []
@@ -277,7 +277,8 @@ class NexiosApp(object):
                             # If a lifespan context manager is provided, use it
                             self.lifespan_manager: Any = self.lifespan_context(self)
                             returned_state = await self.lifespan_manager.__aenter__()
-                            self.state.update(returned_state)
+                            if returned_state:
+                                self.state.update(returned_state)
                         else:
                             # Otherwise, fall back to the default startup handlers
                             await self._startup()
@@ -332,6 +333,7 @@ class NexiosApp(object):
                     summary=route.summary or "",
                     description=route.description,
                     request_body=route.request_model,
+                    request_content_type=getattr(route, "request_content_type", "application/json"),
                     parameters=parameters,  # type:ignore
                     deprecated=route.deprecated,
                     operation_id=route.operation_id,
@@ -833,6 +835,10 @@ class NexiosApp(object):
             """
             ),
         ] = None,
+        request_content_type: Annotated[
+            Literal["application/json", "multipart/form-data", "application/x-www-form-urlencoded"],
+            Doc("Content type for the request body in OpenAPI docs. Defaults to 'application/json'."),
+        ] = "application/json",
         middleware: Annotated[
             List[Any],
             Doc(
@@ -947,6 +953,7 @@ class NexiosApp(object):
             description=description,
             responses=responses,
             request_model=request_model,
+            request_content_type=request_content_type,
             middleware=middleware,
             tags=tags,
             security=security,
@@ -1291,6 +1298,15 @@ class NexiosApp(object):
             """
             ),
         ] = False,
+        request_content_type: Annotated[
+            Optional[Literal["application/json", "application/x-www-form-urlencoded", "multipart/form-data"]],
+            Doc(
+                """
+                Request content type.
+                Example: 'application/json'
+            """
+            ),
+        ] = "application/json",
         **kwargs: Annotated[
             Dict[str, Any],
             Doc(
@@ -1345,6 +1361,7 @@ class NexiosApp(object):
             description=description,
             responses=responses,
             request_model=request_model,
+            request_content_type=request_content_type,
             middleware=middleware,
             tags=tags,
             security=security,
@@ -1493,6 +1510,15 @@ class NexiosApp(object):
             """
             ),
         ] = False,
+         request_content_type: Annotated[
+            Optional[Literal["application/json", "application/x-www-form-urlencoded", "multipart/form-data"]],
+            Doc(
+                """
+                Request content type.
+                Example: 'application/json'
+            """
+            ),
+        ] = "application/json",
         **kwargs: Annotated[
             Dict[str, Any],
             Doc(
@@ -1546,6 +1572,7 @@ class NexiosApp(object):
             description=description,
             responses=responses,
             request_model=request_model,
+            request_content_type=request_content_type,
             middleware=middleware,
             tags=tags,
             security=security,
