@@ -1,7 +1,4 @@
 from .request import Request
 from .response import NexiosResponse as Response
 
-__all__ = [
-    "Request",
-    "Response"
-]
\ No newline at end of file
+__all__ = ["Request", "Response"]
