@@ -3,8 +3,11 @@ from __future__ import annotations
 import typing
 from typing import Any, Dict, ItemsView, Iterator, KeysView, Sequence, ValuesView
 from urllib.parse import SplitResult, parse_qsl, urlencode, urlsplit
-
 from nexios.utils.concurrency import run_in_threadpool
+from pydantic import GetJsonSchemaHandler,GetCoreSchemaHandler
+import pydantic
+from pydantic_core import core_schema
+
 
 Scope = typing.MutableMapping[str, typing.Any]
 Message = typing.MutableMapping[str, typing.Any]
@@ -759,7 +762,31 @@ class UploadedFile:
             f"size={self.size!r}, "
             f"headers={self.headers!r})"
         )
+    @classmethod
+    def __get_pydantic_core_schema__(
+        cls, source: Any, handler: GetCoreSchemaHandler
+    ) -> core_schema.CoreSchema:
+        # treat this type as bytes in validation
+        return core_schema.no_info_after_validator_function(
+            cls,
+            core_schema.bytes_schema()
+        )
 
+    @classmethod
+    def __get_pydantic_json_schema__(
+        cls, core_schema: core_schema.CoreSchema, handler: GetJsonSchemaHandler
+    ) -> JsonSchemaValue:
+        # represent in OpenAPI as a file upload
+        return {
+            "type": "string",
+            "format": "binary",
+        }
+
+    
+    
+ 
+
+    
 
 class FormData(
     MultiDict[str, typing.Union[UploadedFile, str, Sequence[Any]]]  # type:ignore
